# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project does not yet adhere to [Semantic Versioning](https://semver.org/spec/v2.0.0.html)
for setuptools_scm/PEP 440 reasons.

## 1.0.4 Stor Blockchain 2021-12-23

Stor 1.0.4 based on Chia™ 1.2.11

### Fixed

- None

### Added

- None

### Changed

- None

### Deprecated

- None

### Known Issues

- None

## 1.0.3 Stor Blockchain 2021-10-12

Stor 1.0.3 based on Chia™ 1.2.9

### Fixed

- Farm overview counts for NFT plots

### Added

- None

### Changed

- None

### Deprecated

- None

### Known Issues

- None

## 1.0.2 Stor Blockchain 2021-10-07

Stor 1.0.2 based on Chia™ 1.2.9

### Fixed

- None

### Added

- None

### Changed

- None

### Deprecated

- None

### Known Issues

- None

## 1.0.1 Stor Blockchain 2021-08-17

Stor 1.0.1 based on Chia™ 1.2.3

### Fixed

- None

### Added

- None

### Changed

- None

### Deprecated

- None

### Known Issues

- None
